@@ -7,6 +7,9 @@
 # does it submit to any jurisdiction.
 #
 
+from climetlab.helpers import helper
+
+
 # This is needed when running Sphinx on ReadTheDoc
 try:
     from .drivers.magics import Driver
@@ -14,7 +17,6 @@ try:
 except Exception:
     from .drivers.missing import Driver
 
-from importlib import import_module
 
 try:
     from IPython.display import display
@@ -26,28 +28,13 @@ except Exception:
 
 CURRENT_DRIVER = Driver()
 
-HELPERS = {
-    "xarray.core.dataset.Dataset": "xarray",
-    "xarray.core.dataarray.DataArray": "xarray",
-    "numpy.ndarray": "ndarray",
-    "pandas.core.frame.DataFrame": "pandas",
-}
-
 
 def plot_map(data, *args, **kwargs):
     # This is a standalone plot, so we reset the driver
     CURRENT_DRIVER = Driver(*args, **kwargs)
+
     if getattr(data, "plot_map", None) is None:
-
-        fullname = ".".join([data.__class__.__module__, data.__class__.__qualname__])
-
-        name = HELPERS.get(fullname)
-
-        if name is not None:
-            helper = import_module(".helpers.%s" % (name,), package=__name__)
-            data = helper.helper(data, *args, **kwargs)
-        else:
-            raise ValueError("Cannot plot %s" % (fullname,))
+        data = helper(data, *args, **kwargs)
 
     data.plot_map(CURRENT_DRIVER)
 
